# -*- encoding: utf-8 -*-
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import unittest

from gnocchiclient import auth


class GnocchiBasicPluginTest(unittest.TestCase):
    def test_get_headers(self):
        p = auth.GnocchiBasicPlugin("foobar", "http://localhost")
        self.assertEqual({'Authorization': 'basic Zm9vYmFyOg=='},
                         p.get_headers(None))
